summaryrefslogtreecommitdiffstats
path: root/src/Chunk.h
diff options
context:
space:
mode:
authorHowaner <franzi.moos@googlemail.com>2014-02-19 14:45:09 +0100
committerHowaner <franzi.moos@googlemail.com>2014-02-19 14:45:09 +0100
commitd63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052 (patch)
treee2a6645283f80bd664a4bc8d402f52f13824cd14 /src/Chunk.h
parentAdd break to Protocol17x.cpp and use new comment delimiter (diff)
downloadcuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar.gz
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar.bz2
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar.lz
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar.xz
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.tar.zst
cuberite-d63ce62f3bbe4b8e89b8c54af4b71d77bcc7e052.zip
Diffstat (limited to 'src/Chunk.h')
-rw-r--r--src/Chunk.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/Chunk.h b/src/Chunk.h
index 27388deb4..6bec60813 100644
--- a/src/Chunk.h
+++ b/src/Chunk.h
@@ -31,7 +31,7 @@ class cChestEntity;
class cDispenserEntity;
class cFurnaceEntity;
class cNoteEntity;
-class cSkullEntity;
+class cMobHeadEntity;
class cBlockArea;
class cPawn;
class cPickup;
@@ -48,7 +48,7 @@ typedef cItemCallback<cDispenserEntity> cDispenserCallback;
typedef cItemCallback<cFurnaceEntity> cFurnaceCallback;
typedef cItemCallback<cNoteEntity> cNoteBlockCallback;
typedef cItemCallback<cCommandBlockEntity> cCommandBlockCallback;
-typedef cItemCallback<cSkullEntity> cSkullBlockCallback;
+typedef cItemCallback<cMobHeadEntity> cMobHeadBlockCallback;
@@ -245,8 +245,8 @@ public:
/** Calls the callback for the command block at the specified coords; returns false if there's no command block at those coords or callback returns true, returns true if found */
bool DoWithCommandBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cCommandBlockCallback & a_Callback);
- /** Calls the callback for the skull block at the specified coords; returns false if there's no skull block at those coords or callback returns true, returns true if found */
- bool DoWithSkullBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cSkullBlockCallback & a_Callback);
+ /** Calls the callback for the mob head block at the specified coords; returns false if there's no mob header block at those coords or callback returns true, returns true if found */
+ bool DoWithMobHeadBlockAt(int a_BlockX, int a_BlockY, int a_BlockZ, cMobHeadBlockCallback & a_Callback);
/** Retrieves the test on the sign at the specified coords; returns false if there's no sign at those coords, true if found */
bool GetSignLines (int a_BlockX, int a_BlockY, int a_BlockZ, AString & a_Line1, AString & a_Line2, AString & a_Line3, AString & a_Line4); // Lua-accessible